@@ -67,14 +67,14 @@ class Translator:
         r = json.loads(
             r.content.decode('utf-8')
         )
-
+        
         if not client == "dict-chrome-ex":
             return r
 
         _tmp = {
             "raw": TranslatedObject(r),
-            "orig": " ".join([s['orig'] for s in r['sentences'] if 'orig' in s]),
-            "text": " ".join([s['trans'] for s in r['sentences'] if 'trans' in s]),
+            "orig": "".join(s['orig'] for s in r['sentences'] if 'orig' in s),
+            "text": "".join(s['trans'] for s in r['sentences'] if 'trans' in s),
             "orig_raw": [s['orig'] for s in r['sentences'] if 'orig' in s],
             "text_raw": [s['trans'] for s in r['sentences'] if 'trans' in s],
             "lang": r['src']
